/*********************************************************************************
**
**   $Id: WorkOrderTable.cpp,v 1.8 2004/05/24 11:59:49 croftj Exp $
**   Copyright (c) 2004 Joe Croft <joe@croftj.net>
**   
**   This file is part of ah2.
**
**   ah2 is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 2 of the License, or
**   (at your option) any later version.
**
**   Foobar is distributed in the hope that it will be useful,
**   but WITHOUT ANY WARRANTY; without even the implied warranty of
**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**   GNU General Public License for more details.
**
**   You should have received a copy of the GNU General Public License
**   along with Foobar; if not, write to the Free Software
**   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
*********************************************************************************/

#include "WorkOrderTable.h"

static DataFields fields[] =
{
   { "ident",     "WO#",         0,  0,  0,  0,   5,  0,  0, "", NULL, NULL },
   { "closed",    "Closed",      0,  0,  0,  0,   5,  0,  0, "", NULL, NULL },
   { "date_in",   "Date In",     0,  0,  0,  0,   0,  0,  0, "", NULL, NULL },
   { "name",      "Name",        0,  0,  0,  0,  20,  0,  0, "", NULL, NULL },
   { "make",      "Make",        0,  0,  0,  0,   0,  0,  0, "", NULL, NULL },
   { "model",     "Model",       0,  0,  0,  0,   0,  0,  0, "", NULL, NULL },
   { "color",     "Color",       0,  0,  0,  0,   0,  0,  0, "", NULL, NULL },
   { "tag",       "Tag",         0,  0,  0,  0,   7,  0,  0, "", NULL, NULL },
   { "vin",       "Vin",         0,  0,  0,  0,  12,  0,  0, "", NULL, NULL },
   { "parts",     "Parts Total", 0,  0,  0,  0,   0,  0,  0, "", NULL, "money" },
   { "labor",     "Labor Total", 0,  0,  0,  0,   0,  0,  0, "", NULL, "money" },
   {  NULL, NULL, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

WorkOrderTable::WorkOrderTable(QWidget *pParent, const char *pName) :
            DataTable(fields, "workorders_v", 15, pParent, pName)
{
   viewClosed = 0;
   printf("WorkOrderTable::WorkOrderTable(default): Enter- viewCLosed = |%d|\n", viewClosed);
   sortBy("name ASC");
   sortBy("date_in ASC");
   sortBy("closed ASC");
   viewClosed = false;
   customer = 0;
   vehicle = 0;
   begDate = "";
   endDate = "";
   buildFilter();
   refresh();
}

WorkOrderTable::WorkOrderTable(bool _viewClosed, int _customer, int _vehicle, int _parent, QWidget *pParent, const char *pName) :
            DataTable(fields, "workorders_v", 15, pParent, pName)
{
   QString filter;
   viewClosed = _viewClosed;
   vehicle = _vehicle;
   customer = _customer;

   printf("WorkOrderTable::WorkOrderTable(not default): Enter- viewClosed = %d, customer = %d, vehicle = %d\n", viewClosed, customer, vehicle);

   buildFilter();
   sortBy("name ASC");
   sortBy("date_in ASC");
   sortBy("closed ASC");
   refresh();
}

void WorkOrderTable::setVehicle(int _vehicle)
{
   vehicle = _vehicle;   
   buildFilter();
   refresh();
}

void WorkOrderTable::setCustomer(int _customer)
{
   customer = _customer;   
   buildFilter();
   refresh();
}

void WorkOrderTable::setBeginDate(QString _begdate)
{
   begDate = _begdate;
   buildFilter();
   refresh();
}

void WorkOrderTable::setEndDate(QString _enddate)
{
   endDate = _enddate;
   buildFilter();
   refresh();
}


void WorkOrderTable::buildFilter()
{
   QString f;
   QString sparent, svendor, saccount;

   printf("WorkOrderTable::buildFilter(): Enter\n");

   if ( begDate != "" ) 
   {
      if ( f.length() > 0 ) 
         f += " and ";
      f += "date_in >= '" + begDate + "'";
   }
   if ( endDate != "" ) 
   {
      if ( f.length() > 0 ) 
         f += " and ";
      f += "date_in <= '" + endDate + "'";
   }
   if ( vehicle > 0 ) 
   {
      QString svehicle;
      svehicle.setNum(vehicle);
      if ( f.length() > 0 ) 
         f += " and ";
      f += "vehicle = '" + svehicle + "'";
   }
   if ( customer > 0 ) 
   {
      QString scustomer;
      scustomer.setNum(customer);
      if ( f.length() > 0 ) 
         f += " and ";
      f += "customer = '" + scustomer + "'";
   }
   if ( !viewClosed ) 
   {
      if ( f.length() > 0 ) 
         f += " and ";
      f += "closed = 'N'";
   }

   printf("WorkOrderTable::buildFilter(): filter = |%s|\n", (const char*)f);
   setFilter(f);
}

void WorkOrderTable::showClosed(bool x)
{
   viewClosed = x;
   buildFilter();
   refresh();
}
